==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/ByteMatchSetByteMatchTupleFieldToMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property data When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
 * @property type The part of the web request that you want AWS WAF to search for a specified string.
 */
public data class ByteMatchSetByteMatchTupleFieldToMatchArgs(
    public val `data`: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs> {
    override fun toJava():
        com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs =
        com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs.builder()
            .`data`(`data`?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ByteMatchSetByteMatchTupleFieldToMatchArgs].
 */
@PulumiTagMarker
public class ByteMatchSetByteMatchTupleFieldToMatchArgsBuilder internal constructor() {
    private var `data`: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
     */
    @JvmName("mmqxxjhcamvatkkv")
    public suspend fun `data`(`value`: Output<String>) {
        this.`data` = value
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     */
    @JvmName("bhsqsesimlwpsihw")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
     */
    @JvmName("fvaifbfgvgonkxmk")
    public suspend fun `data`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     */
    @JvmName("bwmwcufayjvjfsfm")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ByteMatchSetByteMatchTupleFieldToMatchArgs =
        ByteMatchSetByteMatchTupleFieldToMatchArgs(
            `data` = `data`,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/ByteMatchSetByteMatchTupleFieldToMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property data When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
 * @property type The part of the web request that you want AWS WAF to search for a specified string.
 */
public data class ByteMatchSetByteMatchTupleFieldToMatchArgs(
    public val `data`: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs> {
    override fun toJava(): com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs =
        com.pulumi.aws.wafregional.inputs.ByteMatchSetByteMatchTupleFieldToMatchArgs.builder()
            .`data`(`data`?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ByteMatchSetByteMatchTupleFieldToMatchArgs].
 */
@PulumiTagMarker
public class ByteMatchSetByteMatchTupleFieldToMatchArgsBuilder internal constructor() {
    private var `data`: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
     */
    @JvmName("ndvjtkwgmucwohlw")
    public suspend fun `data`(`value`: Output<String>) {
        this.`data` = value
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     */
    @JvmName("yuxrdakrborytswu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value When the value of Type is HEADER, enter the name of the header that you want AWS WAF to search, for example, User-Agent or Referer. If the value of Type is any other value, omit Data.
     */
    @JvmName("pduyregkpoxundct")
    public suspend fun `data`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`data` = mapped
    }

    /**
     * @param value The part of the web request that you want AWS WAF to search for a specified string.
     */
    @JvmName("ybtmiicicswinwnf")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ByteMatchSetByteMatchTupleFieldToMatchArgs =
        ByteMatchSetByteMatchTupleFieldToMatchArgs(
            `data` = `data`,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
